@@ -67,7 +67,7 @@ def test_anticommutator():
     ac_tall = AntiCommutator(A**2, B)
     assert str(ac) == '{A,B}'
     assert pretty(ac) == '{A,B}'
-    assert upretty(ac) == u('{A,B}')
+    assert upretty(ac) == u'{A,B}'
     assert latex(ac) == r'\left\{A,B\right\}'
     sT(ac, "AntiCommutator(Operator(Symbol('A')),Operator(Symbol('B')))")
     assert str(ac_tall) == '{A**2,B}'
@@ -85,7 +85,7 @@ u("""\
 """)
     assert pretty(ac_tall) == ascii_str
     assert upretty(ac_tall) == ucode_str
-    assert latex(ac_tall) == r'\left\{\left(A\right)^{2},B\right\}'
+    assert latex(ac_tall) == r'\left\{A^{2},B\right\}'
     sT(ac_tall, "AntiCommutator(Pow(Operator(Symbol('A')), Integer(2)),Operator(Symbol('B')))")
 
 
@@ -178,7 +178,7 @@ def test_commutator():
     c_tall = Commutator(A**2, B)
     assert str(c) == '[A,B]'
     assert pretty(c) == '[A,B]'
-    assert upretty(c) == u('[A,B]')
+    assert upretty(c) == u'[A,B]'
     assert latex(c) == r'\left[A,B\right]'
     sT(c, "Commutator(Operator(Symbol('A')),Operator(Symbol('B')))")
     assert str(c_tall) == '[A**2,B]'
@@ -194,14 +194,14 @@ u("""\
 """)
     assert pretty(c_tall) == ascii_str
     assert upretty(c_tall) == ucode_str
-    assert latex(c_tall) == r'\left[\left(A\right)^{2},B\right]'
+    assert latex(c_tall) == r'\left[A^{2},B\right]'
     sT(c_tall, "Commutator(Pow(Operator(Symbol('A')), Integer(2)),Operator(Symbol('B')))")
 
 
 def test_constants():
     assert str(hbar) == 'hbar'
     assert pretty(hbar) == 'hbar'
-    assert upretty(hbar) == u('ℏ')
+    assert upretty(hbar) == u'ℏ'
     assert latex(hbar) == r'\hbar'
     sT(hbar, "HBar()")
 
@@ -244,7 +244,7 @@ def test_gate():
     g4 = UGate((0,), uMat)
     assert str(g1) == '1(2)'
     assert pretty(g1) == '1 \n 2'
-    assert upretty(g1) == u('1 \n 2')
+    assert upretty(g1) == u'1 \n 2'
     assert latex(g1) == r'1_{2}'
     sT(g1, "IdentityGate(Integer(2))")
     assert str(g1*q) == '1(2)*|10101>'
@@ -321,7 +321,7 @@ def test_hilbert():
     h4 = L2(Interval(0, oo))
     assert str(h1) == 'H'
     assert pretty(h1) == 'H'
-    assert upretty(h1) == u('H')
+    assert upretty(h1) == u'H'
     assert latex(h1) == r'\mathcal{H}'
     sT(h1, "HilbertSpace()")
     assert str(h2) == 'C(2)'
@@ -341,10 +341,10 @@ C \
     sT(h2, "ComplexSpace(Integer(2))")
     assert str(h3) == 'F'
     assert pretty(h3) == 'F'
-    assert upretty(h3) == u('F')
+    assert upretty(h3) == u'F'
     assert latex(h3) == r'\mathcal{F}'
     sT(h3, "FockSpace()")
-    assert str(h4) == 'L2([0, oo))'
+    assert str(h4) == 'L2(Interval(0, oo))'
     ascii_str = \
 """\
  2\n\
@@ -418,24 +418,24 @@ def test_innerproduct():
     ip_tall3 = InnerProduct(Bra(x/2), Ket(x))
     assert str(ip1) == '<psi|psi>'
     assert pretty(ip1) == '<psi|psi>'
-    assert upretty(ip1) == u('⟨ψ❘ψ⟩')
+    assert upretty(ip1) == u'⟨ψ❘ψ⟩'
     assert latex(
         ip1) == r'\left\langle \psi \right. {\left|\psi\right\rangle }'
     sT(ip1, "InnerProduct(Bra(Symbol('psi')),Ket(Symbol('psi')))")
     assert str(ip2) == '<psi;t|psi;t>'
     assert pretty(ip2) == '<psi;t|psi;t>'
-    assert upretty(ip2) == u('⟨ψ;t❘ψ;t⟩')
+    assert upretty(ip2) == u'⟨ψ;t❘ψ;t⟩'
     assert latex(ip2) == \
         r'\left\langle \psi;t \right. {\left|\psi;t\right\rangle }'
     sT(ip2, "InnerProduct(TimeDepBra(Symbol('psi'),Symbol('t')),TimeDepKet(Symbol('psi'),Symbol('t')))")
     assert str(ip3) == "<1,1|1,1>"
     assert pretty(ip3) == '<1,1|1,1>'
-    assert upretty(ip3) == u('⟨1,1❘1,1⟩')
+    assert upretty(ip3) == u'⟨1,1❘1,1⟩'
     assert latex(ip3) == r'\left\langle 1,1 \right. {\left|1,1\right\rangle }'
     sT(ip3, "InnerProduct(JzBra(Integer(1),Integer(1)),JzKet(Integer(1),Integer(1)))")
     assert str(ip4) == "<1,1,j1=1,j2=1|1,1,j1=1,j2=1>"
     assert pretty(ip4) == '<1,1,j1=1,j2=1|1,1,j1=1,j2=1>'
-    assert upretty(ip4) == u('⟨1,1,j₁=1,j₂=1❘1,1,j₁=1,j₂=1⟩')
+    assert upretty(ip4) == u'⟨1,1,j₁=1,j₂=1❘1,1,j₁=1,j₂=1⟩'
     assert latex(ip4) == \
         r'\left\langle 1,1,j_{1}=1,j_{2}=1 \right. {\left|1,1,j_{1}=1,j_{2}=1\right\rangle }'
     sT(ip4, "InnerProduct(JzBraCoupled(Integer(1),Integer(1),Tuple(Integer(1), Integer(1)),Tuple(Tuple(Integer(1), Integer(2), Integer(1)))),JzKetCoupled(Integer(1),Integer(1),Tuple(Integer(1), Integer(1)),Tuple(Tuple(Integer(1), Integer(2), Integer(1)))))")
@@ -513,7 +513,7 @@ def test_operator():
     op = OuterProduct(Ket(), Bra())
     assert str(a) == 'A'
     assert pretty(a) == 'A'
-    assert upretty(a) == u('A')
+    assert upretty(a) == u'A'
     assert latex(a) == 'A'
     sT(a, "Operator(Symbol('A'))")
     assert str(inv) == 'A**(-1)'
@@ -529,14 +529,14 @@ A  \
 """)
     assert pretty(inv) == ascii_str
     assert upretty(inv) == ucode_str
-    assert latex(inv) == r'\left(A\right)^{-1}'
+    assert latex(inv) == r'A^{-1}'
     sT(inv, "Pow(Operator(Symbol('A')), Integer(-1))")
     assert str(d) == 'DifferentialOperator(Derivative(f(x), x),f(x))'
     ascii_str = \
 """\
                     /d            \\\n\
 DifferentialOperator|--(f(x)),f(x)|\n\
-                    \dx           /\
+                    \\dx           /\
 """
     ucode_str = \
 u("""\
@@ -551,12 +551,12 @@ DifferentialOperator⎜──(f(x)),f(x)⎟\n\
     sT(d, "DifferentialOperator(Derivative(Function('f')(Symbol('x')), Symbol('x')),Function('f')(Symbol('x')))")
     assert str(b) == 'Operator(B,t,1/2)'
     assert pretty(b) == 'Operator(B,t,1/2)'
-    assert upretty(b) == u('Operator(B,t,1/2)')
+    assert upretty(b) == u'Operator(B,t,1/2)'
     assert latex(b) == r'Operator\left(B,t,\frac{1}{2}\right)'
     sT(b, "Operator(Symbol('B'),Symbol('t'),Rational(1, 2))")
     assert str(op) == '|psi><psi|'
     assert pretty(op) == '|psi><psi|'
-    assert upretty(op) == u('❘ψ⟩⟨ψ❘')
+    assert upretty(op) == u'❘ψ⟩⟨ψ❘'
     assert latex(op) == r'{\left|\psi\right\rangle }{\left\langle \psi\right|}'
     sT(op, "OuterProduct(Ket(Symbol('psi')),Bra(Symbol('psi')))")
 
@@ -565,7 +565,7 @@ def test_qexpr():
     q = QExpr('q')
     assert str(q) == 'q'
     assert pretty(q) == 'q'
-    assert upretty(q) == u('q')
+    assert upretty(q) == u'q'
     assert latex(q) == r'q'
     sT(q, "QExpr(Symbol('q'))")
 
@@ -575,12 +575,12 @@ def test_qubit():
     q2 = IntQubit(8)
     assert str(q1) == '|0101>'
     assert pretty(q1) == '|0101>'
-    assert upretty(q1) == u('❘0101⟩')
+    assert upretty(q1) == u'❘0101⟩'
     assert latex(q1) == r'{\left|0101\right\rangle }'
     sT(q1, "Qubit(Integer(0),Integer(1),Integer(0),Integer(1))")
     assert str(q2) == '|8>'
     assert pretty(q2) == '|8>'
-    assert upretty(q2) == u('❘8⟩')
+    assert upretty(q2) == u'❘8⟩'
     assert latex(q2) == r'{\left|8\right\rangle }'
     sT(q2, "IntQubit(8)")
 
@@ -643,41 +643,41 @@ J \n\
     sT(Jz, "JzOp(Symbol('J'))")
     assert str(ket) == '|1,0>'
     assert pretty(ket) == '|1,0>'
-    assert upretty(ket) == u('❘1,0⟩')
+    assert upretty(ket) == u'❘1,0⟩'
     assert latex(ket) == r'{\left|1,0\right\rangle }'
     sT(ket, "JzKet(Integer(1),Integer(0))")
     assert str(bra) == '<1,0|'
     assert pretty(bra) == '<1,0|'
-    assert upretty(bra) == u('⟨1,0❘')
+    assert upretty(bra) == u'⟨1,0❘'
     assert latex(bra) == r'{\left\langle 1,0\right|}'
     sT(bra, "JzBra(Integer(1),Integer(0))")
     assert str(cket) == '|1,0,j1=1,j2=2>'
     assert pretty(cket) == '|1,0,j1=1,j2=2>'
-    assert upretty(cket) == u('❘1,0,j₁=1,j₂=2⟩')
+    assert upretty(cket) == u'❘1,0,j₁=1,j₂=2⟩'
     assert latex(cket) == r'{\left|1,0,j_{1}=1,j_{2}=2\right\rangle }'
     sT(cket, "JzKetCoupled(Integer(1),Integer(0),Tuple(Integer(1), Integer(2)),Tuple(Tuple(Integer(1), Integer(2), Integer(1))))")
     assert str(cbra) == '<1,0,j1=1,j2=2|'
     assert pretty(cbra) == '<1,0,j1=1,j2=2|'
-    assert upretty(cbra) == u('⟨1,0,j₁=1,j₂=2❘')
+    assert upretty(cbra) == u'⟨1,0,j₁=1,j₂=2❘'
     assert latex(cbra) == r'{\left\langle 1,0,j_{1}=1,j_{2}=2\right|}'
     sT(cbra, "JzBraCoupled(Integer(1),Integer(0),Tuple(Integer(1), Integer(2)),Tuple(Tuple(Integer(1), Integer(2), Integer(1))))")
     assert str(cket_big) == '|1,0,j1=1,j2=2,j3=3,j(1,2)=3>'
     # TODO: Fix non-unicode pretty printing
     # i.e. j1,2 -> j(1,2)
     assert pretty(cket_big) == '|1,0,j1=1,j2=2,j3=3,j1,2=3>'
-    assert upretty(cket_big) == u('❘1,0,j₁=1,j₂=2,j₃=3,j₁,₂=3⟩')
+    assert upretty(cket_big) == u'❘1,0,j₁=1,j₂=2,j₃=3,j₁,₂=3⟩'
     assert latex(cket_big) == \
         r'{\left|1,0,j_{1}=1,j_{2}=2,j_{3}=3,j_{1,2}=3\right\rangle }'
     sT(cket_big, "JzKetCoupled(Integer(1),Integer(0),Tuple(Integer(1), Integer(2), Integer(3)),Tuple(Tuple(Integer(1), Integer(2), Integer(3)), Tuple(Integer(1), Integer(3), Integer(1))))")
     assert str(cbra_big) == '<1,0,j1=1,j2=2,j3=3,j(1,2)=3|'
-    assert pretty(cbra_big) == u('<1,0,j1=1,j2=2,j3=3,j1,2=3|')
-    assert upretty(cbra_big) == u('⟨1,0,j₁=1,j₂=2,j₃=3,j₁,₂=3❘')
+    assert pretty(cbra_big) == u'<1,0,j1=1,j2=2,j3=3,j1,2=3|'
+    assert upretty(cbra_big) == u'⟨1,0,j₁=1,j₂=2,j₃=3,j₁,₂=3❘'
     assert latex(cbra_big) == \
         r'{\left\langle 1,0,j_{1}=1,j_{2}=2,j_{3}=3,j_{1,2}=3\right|}'
     sT(cbra_big, "JzBraCoupled(Integer(1),Integer(0),Tuple(Integer(1), Integer(2), Integer(3)),Tuple(Tuple(Integer(1), Integer(2), Integer(3)), Tuple(Integer(1), Integer(3), Integer(1))))")
     assert str(rot) == 'R(1,2,3)'
     assert pretty(rot) == 'R (1,2,3)'
-    assert upretty(rot) == u('ℛ (1,2,3)')
+    assert upretty(rot) == u'ℛ (1,2,3)'
     assert latex(rot) == r'\mathcal{R}\left(1,2,3\right)'
     sT(rot, "Rotation(Integer(1),Integer(2),Integer(3))")
     assert str(bigd) == 'WignerD(1, 2, 3, 4, 5, 6)'
@@ -726,12 +726,12 @@ def test_state():
     tket = TimeDepKet()
     assert str(bra) == '<psi|'
     assert pretty(bra) == '<psi|'
-    assert upretty(bra) == u('⟨ψ❘')
+    assert upretty(bra) == u'⟨ψ❘'
     assert latex(bra) == r'{\left\langle \psi\right|}'
     sT(bra, "Bra(Symbol('psi'))")
     assert str(ket) == '|psi>'
     assert pretty(ket) == '|psi>'
-    assert upretty(ket) == u('❘ψ⟩')
+    assert upretty(ket) == u'❘ψ⟩'
     assert latex(ket) == r'{\left|\psi\right\rangle }'
     sT(ket, "Ket(Symbol('psi'))")
     assert str(bra_tall) == '<x/2|'
@@ -773,13 +773,13 @@ u("""\
     assert latex(ket_tall) == r'{\left|\frac{x}{2}\right\rangle }'
     sT(ket_tall, "Ket(Mul(Rational(1, 2), Symbol('x')))")
     assert str(tbra) == '<psi;t|'
-    assert pretty(tbra) == u('<psi;t|')
-    assert upretty(tbra) == u('⟨ψ;t❘')
+    assert pretty(tbra) == u'<psi;t|'
+    assert upretty(tbra) == u'⟨ψ;t❘'
     assert latex(tbra) == r'{\left\langle \psi;t\right|}'
     sT(tbra, "TimeDepBra(Symbol('psi'),Symbol('t'))")
     assert str(tket) == '|psi;t>'
     assert pretty(tket) == '|psi;t>'
-    assert upretty(tket) == u('❘ψ;t⟩')
+    assert upretty(tket) == u'❘ψ;t⟩'
     assert latex(tket) == r'{\left|\psi;t\right\rangle }'
     sT(tket, "TimeDepKet(Symbol('psi'),Symbol('t'))")
 
@@ -788,7 +788,7 @@ def test_tensorproduct():
     tp = TensorProduct(JzKet(1, 1), JzKet(1, 0))
     assert str(tp) == '|1,1>x|1,0>'
     assert pretty(tp) == '|1,1>x |1,0>'
-    assert upretty(tp) == u('❘1,1⟩⨂ ❘1,0⟩')
+    assert upretty(tp) == u'❘1,1⟩⨂ ❘1,0⟩'
     assert latex(tp) == \
         r'{{\left|1,1\right\rangle }}\otimes {{\left|1,0\right\rangle }}'
     sT(tp, "TensorProduct(JzKet(Integer(1),Integer(1)), JzKet(Integer(1),Integer(0)))")
@@ -809,7 +809,7 @@ def test_big_expr():
                  |/                                   +\\         |                                 \n\
     2  / +    +\\ <|                    /d            \\ |   +    +>                                 \n\
 /J \\ x \\A  + B /*||DifferentialOperator|--(f(x)),f(x)| | ,A  + B |*(<1,0| + <1,1|)*(|0,0> + |1,-1>)\n\
-\\ z/             \\\\                    \dx           / /         /                                 \
+\\ z/             \\\\                    \\dx           / /         /                                 \
 """
     ucode_str = \
 u("""\
@@ -822,7 +822,7 @@ u("""\
     assert pretty(e1) == ascii_str
     assert upretty(e1) == ucode_str
     assert latex(e1) == \
-        r'{\left(J_z\right)^{2}}\otimes \left({A^{\dag} + B^{\dag}}\right) \left\{\left(DifferentialOperator\left(\frac{d}{d x} f{\left (x \right )},f{\left (x \right )}\right)^{\dag}\right)^{3},A^{\dag} + B^{\dag}\right\} \left({\left\langle 1,0\right|} + {\left\langle 1,1\right|}\right) \left({\left|0,0\right\rangle } + {\left|1,-1\right\rangle }\right)'
+        r'{J_z^{2}}\otimes \left({A^{\dag} + B^{\dag}}\right) \left\{\left(DifferentialOperator\left(\frac{d}{d x} f{\left (x \right )},f{\left (x \right )}\right)^{\dag}\right)^{3},A^{\dag} + B^{\dag}\right\} \left({\left\langle 1,0\right|} + {\left\langle 1,1\right|}\right) \left({\left|0,0\right\rangle } + {\left|1,-1\right\rangle }\right)'
     sT(e1, "Mul(TensorProduct(Pow(JzOp(Symbol('J')), Integer(2)), Add(Dagger(Operator(Symbol('A'))), Dagger(Operator(Symbol('B'))))), AntiCommutator(Pow(Dagger(DifferentialOperator(Derivative(Function('f')(Symbol('x')), Symbol('x')),Function('f')(Symbol('x')))), Integer(3)),Add(Dagger(Operator(Symbol('A'))), Dagger(Operator(Symbol('B'))))), Add(JzBra(Integer(1),Integer(0)), JzBra(Integer(1),Integer(1))), Add(JzKet(Integer(0),Integer(0)), JzKet(Integer(1),Integer(-1))))")
     assert str(e2) == '[Jz**2,A + B]*{E**(-2),Dagger(D)*Dagger(C)}*[J2,Jz]'
     ascii_str = \
@@ -840,7 +840,7 @@ u("""\
     assert pretty(e2) == ascii_str
     assert upretty(e2) == ucode_str
     assert latex(e2) == \
-        r'\left[\left(J_z\right)^{2},A + B\right] \left\{\left(E\right)^{-2},D^{\dag} C^{\dag}\right\} \left[J^2,J_z\right]'
+        r'\left[J_z^{2},A + B\right] \left\{E^{-2},D^{\dag} C^{\dag}\right\} \left[J^2,J_z\right]'
     sT(e2, "Mul(Commutator(Pow(JzOp(Symbol('J')), Integer(2)),Add(Operator(Symbol('A')), Operator(Symbol('B')))), AntiCommutator(Pow(Operator(Symbol('E')), Integer(-2)),Mul(Dagger(Operator(Symbol('D'))), Dagger(Operator(Symbol('C'))))), Commutator(J2Op(Symbol('J')),JzOp(Symbol('J'))))")
     assert str(e3) == \
         "Wigner3j(1, 2, 3, 4, 5, 6)*[Dagger(B) + A,C + D]x(-J2 + Jz)*|1,0><1,1|*(|1,0,j1=1,j2=1> + |1,1,j1=1,j2=1>)x|1,-1,j1=1,j2=1>"
@@ -863,11 +863,11 @@ u("""\
     assert latex(e3) == \
         r'\left(\begin{array}{ccc} 1 & 3 & 5 \\ 2 & 4 & 6 \end{array}\right) {\left[B^{\dag} + A,C + D\right]}\otimes \left({- J^2 + J_z}\right) {\left|1,0\right\rangle }{\left\langle 1,1\right|} \left({{\left|1,0,j_{1}=1,j_{2}=1\right\rangle } + {\left|1,1,j_{1}=1,j_{2}=1\right\rangle }}\right)\otimes {{\left|1,-1,j_{1}=1,j_{2}=1\right\rangle }}'
     sT(e3, "Mul(Wigner3j(Integer(1), Integer(2), Integer(3), Integer(4), Integer(5), Integer(6)), TensorProduct(Commutator(Add(Dagger(Operator(Symbol('B'))), Operator(Symbol('A'))),Add(Operator(Symbol('C')), Operator(Symbol('D')))), Add(Mul(Integer(-1), J2Op(Symbol('J'))), JzOp(Symbol('J')))), OuterProduct(JzKet(Integer(1),Integer(0)),JzBra(Integer(1),Integer(1))), TensorProduct(Add(JzKetCoupled(Integer(1),Integer(0),Tuple(Integer(1), Integer(1)),Tuple(Tuple(Integer(1), Integer(2), Integer(1)))), JzKetCoupled(Integer(1),Integer(1),Tuple(Integer(1), Integer(1)),Tuple(Tuple(Integer(1), Integer(2), Integer(1))))), JzKetCoupled(Integer(1),Integer(-1),Tuple(Integer(1), Integer(1)),Tuple(Tuple(Integer(1), Integer(2), Integer(1))))))")
-    assert str(e4) == '(C(1)*C(2)+F**2)*(L2([0, oo))+H)'
+    assert str(e4) == '(C(1)*C(2)+F**2)*(L2(Interval(0, oo))+H)'
     ascii_str = \
 """\
 // 1    2\\    x2\\   / 2    \\\n\
-\\\\C  x C / + F  / x \L  + H/\
+\\\\C  x C / + F  / x \\L  + H/\
 """
     ucode_str = \
 u("""\
@@ -883,5 +883,5 @@ u("""\
 
 def _test_sho1d():
     ad = RaisingOp('a')
-    assert pretty(ad) == u(' \N{DAGGER}\na ')
+    assert pretty(ad) == u' \N{DAGGER}\na '
     assert latex(ad) == 'a^{\\dag}'
