@@ -10,7 +10,9 @@
 """
 from .solvers import solve, solve_linear_system, solve_linear_system_LU, \
     solve_undetermined_coeffs, nsolve, solve_linear, checksol, \
-    det_quick, inv_quick
+    det_quick, inv_quick, check_assumptions
+
+from .diophantine import diophantine
 
 from .recurr import rsolve, rsolve_poly, rsolve_ratio, rsolve_hyper
 
@@ -29,4 +31,4 @@ from .inequalities import reduce_inequalities, reduce_abs_inequality, \
 
 from .decompogen import decompogen
 
-from .solveset import solveset, linsolve, linear_eq_to_matrix
+from .solveset import solveset, linsolve, linear_eq_to_matrix, nonlinsolve, substitution
